@@ -19,7 +19,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(CONFIG CONFIG_module);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 our (%CONFIG, $IS_TEST, $IS_TEST_CONFIG, %SIGNO, $CONFIG_FILE);
 
@@ -159,7 +159,7 @@ sub CONFIG_external_program {
     my $xprogram = $external_program;
     $xprogram =~ s{^/}{};
     if (-w '/dev/null') {
-	my $which = qx(which $xprogram 2>/dev/null); ## no critic (Backtick)
+	my $which = qx(which $xprogram 2> /dev/null); ## no critic (Backtick)
 	$which =~ s{\s+$}{};
 	if ($which && -x $which) {
 	    if ($IS_TEST_CONFIG) {
@@ -224,14 +224,14 @@ sub load_config_file {
 		$Forks::Super::QUEUE_INTERRUPT = $val;
 	    } elsif ($key eq 'QUEUE_MONITOR_FREQ') {
                 no warnings 'once';
-		$Forks::Super::Queue::QUEUE_MONITOR_FREQ = $val || 30;
+		$Forks::Super::Deferred::QUEUE_MONITOR_FREQ = $val || 30;
                 no warnings 'once';
 	    } elsif ($key eq 'QUEUE_MONITOR_LIFESPAN') {
                 no warnings 'once';
-		$Forks::Super::Queue::QUEUE_MONITOR_LIFESPAN = $val;
+		$Forks::Super::Deferred::QUEUE_MONITOR_LIFESPAN = $val;
 	    } elsif ($key eq 'QUEUE_DEBUG') {
                 no warnings 'once';
-		$Forks::Super::Queue::QUEUE_DEBUG = $val;
+		$Forks::Super::Deferred::QUEUE_DEBUG = $val;
 	    } elsif ($key eq 'SIG_DEBUG') {
                 no warnings 'once';
 		$Forks::Super::Sigchld::SIG_DEBUG = $val;
