@@ -11,7 +11,7 @@ use Forks::Super::Util qw(is_number qualify_sub_name
 use Forks::Super::Config qw(:all);
 use Forks::Super::Job::Ipc;   # does windows prefer to load Ipc before Timeout?
 use Forks::Super::Job::Timeout;
-use Forks::Super::Queue qw(queue_job);
+use Forks::Super::Deferred qw(queue_job);
 use Forks::Super::Job::OS;
 use Forks::Super::Job::Callback qw(run_callback);
 use Signals::XSIG;
@@ -26,7 +26,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -700,37 +700,42 @@ sub _postlaunch_daemon_parent {
     my $new_pid;
     my $_t = Time::HiRes::time();
 
-    # TODO - can we communicate the daemon pid without file IPC
-    for (my $try=1; defined($job->{daemon_ipc}) && $try<=50; $try++) {
-	if (-f $job->{daemon_ipc} . '.ready') {
-	    if (open my $fh, '<', $job->{daemon_ipc}) {
-		$new_pid = <$fh>;
-		close $fh;
-		unlink $job->{daemon_ipc}, $job->{daemon_ipc} . '.ready';
-	    } else {
-		carp "Forks::Super: could not receive daemon pid: $!";
-		Forks::Super::Util::pause(0.002*$try*$try*$try,$try<3);
-		next;
-	    }
+    if (defined $job->{daemon_ipc_pipe}) {
+        $new_pid = __read_from_pipe( $job->{daemon_ipc_pipe}[0] );
+        close $job->{daemon_ipc_pipe}[0];
+        close $job->{daemon_ipc_pipe}[1];
+    } else {
+        for (my $try=1; defined($job->{daemon_ipc}) && $try<=50; $try++) {
+            if (-f $job->{daemon_ipc} . '.ready') {
+                if (open my $fh, '<', $job->{daemon_ipc}) {
+                    $new_pid = <$fh>;
+                    close $fh;
+                    unlink $job->{daemon_ipc}, $job->{daemon_ipc} . '.ready';
+                } else {
+                    carp "Forks::Super: could not receive daemon pid: $!";
+                    Forks::Super::Util::pause(0.002*$try*$try*$try,$try<3);
+                    next;
+                }
 
-	    if ($Forks::Super::Debug::DEBUG) {
-		debug("daemon job pid is $new_pid (try=$try) ",
-		      't=',Time::HiRes::time()-$_t,'s');
-	    }
+                if ($job->{debug}) {
+                    debug("daemon job pid is $new_pid (try=$try) ",
+                          't=',Time::HiRes::time()-$_t,'s');
+                }
 
-	    ($new_pid) = $new_pid =~ /([-\d]*)/;
-	    if ($try >= 10) {
-		carp 'Forks::Super::fork: ',
-		  	'managed to communicate with the daemon process ',
-		  	"on the $try-th try ...";
-	    }
-	    last;
-	} elsif ($try == 50) {
-	    carp 'Forks::Super::fork: ',
-	          'failed to communicate with new daemon process';
-	} else {
-	    Forks::Super::Util::pause(0.002*$try*$try*$try,$try<3);
-	}
+                ($new_pid) = $new_pid =~ /([-\d]*)/;
+                if ($try >= 10) {
+                    carp 'Forks::Super::fork: ',
+                        'managed to communicate with the daemon process ',
+                        "on the $try-th try ...";
+                }
+                last;
+            } elsif ($try == 50) {
+                carp 'Forks::Super::fork: ',
+                    'failed to communicate with new daemon process';
+            } else {
+                Forks::Super::Util::pause(0.002*$try*$try*$try,$try<3);
+            }
+        }
     }
     if ($new_pid) {
 	$job->{intermediate_pid} = $pid;
@@ -798,8 +803,10 @@ sub _postlaunch_daemon_child_Win32 {
 	}
     }
 
-    {
-	no warnings 'io';
+    if ($job->{daemon_ipc_pipe}) {
+        syswrite $job->{daemon_ipc_pipe}[1], "$p2\n";
+        close $job->{daemon_ipc_pipe}[1];
+    } else {
 	my $f = $job->{daemon_ipc};
 	if (open my $fh, '>', "$f.tmp") {
 	    print $fh $p2;
@@ -818,14 +825,14 @@ sub _postlaunch_daemon_child_Win32 {
 sub _postlaunch_daemon_child {
     my $job = shift;
     debug("child $$ forking again to create daemon process")
-	if $Forks::Super::Debug::DEBUG;
+	if $job->{debug};
 
 
 
     # following Proc::Daemon's lead:
     # 1. The script forks a child (already done)
     # 2. The child changes the current working directory.
-    $job->_chdir_for_daemon($job->{dir});
+    $job->_chdir_for_daemon;
 
     # 3. The child clears the file creation mask
     # if $job->{umask} is set, umask will be reset in _config_child
@@ -856,8 +863,11 @@ sub _postlaunch_daemon_child {
     }
 
     # 9. transfer pid of second child from first child to parent
+    if ($job->{daemon_ipc_pipe}) {
+        syswrite $job->{daemon_ipc_pipe}[1], "$p2\n";
+        close $job->{daemon_ipc_pipe}[1];
+    } else
     {
-	no warnings 'io';
 	my $f = $job->{daemon_ipc};
 	if (open my $fh, '>', "$f.tmp") {
 	    print $fh $p2;
@@ -884,8 +894,13 @@ sub _postlaunch_daemon_grandchild {
 
     # 6. close all open file descriptors
     close STDIN;
+    open STDIN, '<', Forks::Super::Util::DEVNULL();
     close STDOUT;
-    close STDERR if ! defined $job->{'_daemon_dont_close_2'};
+    open STDOUT, '>', Forks::Super::Util::DEVNULL();
+    if (! defined $job->{'_daemon_dont_close_2'}) {
+        close STDERR;
+        open STDERR, '>', Forks::Super::Util::DEVNULL();
+    }
     my $max_fh = $Forks::Super::SysInfo::MAX_OPEN_FH;
     if ($max_fh < 256) {
 	$max_fh = 256;
@@ -905,7 +920,8 @@ sub _postlaunch_daemon_grandchild {
 }
 
 sub _chdir_for_daemon {
-    my ($job,$dir) = @_;
+    my ($job) = @_;
+    my $dir = $job->{dir};
     if (!defined($dir)) {
         chdir '/';
     } elsif (!chdir $dir) {
@@ -1008,7 +1024,7 @@ sub _postlaunch_child_to_exec {
     $job->set_signal_pid($WIN32_PROC_PID);
     my $z = CORE::waitpid $WIN32_PROC_PID, 0;
     my $c1 = $?;
-    if ($Forks::Super::Debug::DEBUG) {
+    if ($job->{debug}) {
 	debug("waitpid $WIN32_PROC_PID ==> $z");
     }
     deinit_child() unless $job->{is_emulation};
@@ -1088,9 +1104,6 @@ sub _postlaunch_child_to_remote_cmd {
     debug("Executing command [ @cmd ] on "
           . $remote->{host}) if $job->{debug};
 
-    open my $ZZZTTY,'+<','/dev/tty';
-#    print $ZZZTTY "_postlaunch_child_to_remote_cmd called\n";
-
     my $retries = $job->{retries} || 0;
     my $this_pid = $$;
 
@@ -1120,7 +1133,7 @@ sub _postlaunch_child_to_remote_cmd {
             }
 
             untie *STDIN;
-            open STDIN,"</dev/null";
+            open STDIN,"<",&Forks::Super::Util::DEVNULL;
             my $ssh = Net::OpenSSH->new($host,%opts);
             croak $ssh->error if $ssh->error;
             $job->set_signal_pid($ssh->get_master_pid);
@@ -1229,7 +1242,6 @@ sub set_signal_pid {
     my ($job, $signal_pid) = @_;
     $job->{signal_pid} = $signal_pid;
 
-    no warnings 'io';  # Win32 can open fd 0, trigger "reopen STDIN for output"
     if (defined $job->{signal_ipc}) {
 	if (open my $fh, '>', $job->{signal_ipc} . '.tmp') {
 	    print $fh $signal_pid;
@@ -1242,6 +1254,9 @@ sub set_signal_pid {
 	    carp 'Forks::Super::set_signal_pid: ',
 	        "child was unable to communicate its other PID to parent: $!";
 	}
+    } elsif (defined $job->{signal_ipc_pipe}) {
+        syswrite $job->{signal_ipc_pipe}[1], $signal_pid . "\n";
+        close $job->{signal_ipc_pipe}[1];
     } elsif (0) {
 	no warnings 'uninitialized';
 	carp 'Forks::Super::set_signal_pid: signal IPC file not specified ',
@@ -1259,7 +1274,7 @@ sub signal_pids {
     my $signal_pid = $job->signal_pid;
 
     if (defined $job->{real_pid} && $job->{real_pid} != $signal_pid) {
-	if ($Forks::Super::Debug::DEBUG) {
+	if ($job->{debug}) {
 	    debug("signal pids for $job are $signal_pid,", $job->{real_pid});
 	}
 
@@ -1267,7 +1282,7 @@ sub signal_pids {
 	#return ($signal_pid, $job->{real_pid});
 	return ($signal_pid);
     } else {
-	if ($Forks::Super::Debug::DEBUG) {
+	if ($job->{debug}) {
 	    debug("signal pids for $job is $signal_pid");
 	}
 	return ($signal_pid);
@@ -1277,7 +1292,8 @@ sub signal_pids {
 sub signal_pid {
     my $job = shift;
 
-    if ($job->{signal_ipc} && !defined $job->{signal_pid}) {
+    if (($job->{signal_ipc} || $job->{signal_ipc_pipe}) &&
+            !defined $job->{signal_pid}) {
 	$job->_read_signal_pid;
     }
     if ($job->{debug} && defined $job->{signal_pid}) {
@@ -1286,14 +1302,57 @@ sub signal_pid {
     return $job->{signal_pid} || $job->{real_pid};
 }
 
+sub __read_from_pipe {
+    my $pipe = shift;
+    my ($rin,$ein,$rout,$eout) = ('');
+    vec($rin, fileno($pipe), 1) = 1;
+    $ein = $rin;
+    my ($nfound,$timeleft);
+    for my $try (1 .. 5) {
+        my $timeout = 0.002 * $try * $try * $try;
+        ($nfound, $timeleft) = select($rout=$rin, undef, $eout=$ein, $timeout);
+        if ($nfound) {
+            my $line = '';
+            my $ch;
+            for (;;) {
+                $ch = getc($pipe);
+                last if !defined($ch) || $ch eq "\n";
+                $line .= $ch;
+            }
+            return $line;
+        }
+    }
+    return;
+}
+
 sub _read_signal_pid {
     my $job = shift;
 
-    if (!defined $job->{signal_pid}) {
-	for my $try (1 .. 5) {
-	    last if -f $job->{signal_ipc};
-	    Forks::Super::Util::pause(0.002*$try*$try*$try, $try<3);
-	}
+    if (defined $job->{signal_ipc_pipe}) {
+        my $pid = __read_from_pipe( $job->{signal_ipc_pipe}[0] );
+        if ($pid) {
+            $job->{signal_pid} = $pid;
+            if ($^O eq 'MSWin32') {
+                $job->{pgid} = $job->{signal_pid};
+            }
+            close $job->{signal_ipc_pipe}[0];
+            close $job->{signal_ipc_pipe}[1];
+            if ($job->{debug}) {
+                debug('parent forwarding signals for ', 
+                      $job->{real_pid}, ' to ', $job->{signal_pid});
+            }
+            return;
+        } elsif ($job->{debug}) {
+            debug('no signal pid read from signal ipc pipe ...');
+        }
+        return;
+    }
+
+    if (!defined $job->{signal_pid} && $job->{signal_ipc}) {
+        for my $try (1 .. 5) {
+            last if -f $job->{signal_ipc};
+            Forks::Super::Util::pause(0.002*$try*$try*$try, $try<3);
+        }
     }
     if (-f $job->{signal_ipc}) {
 	for my $try (1..2) {
@@ -1308,7 +1367,7 @@ sub _read_signal_pid {
 		if ($^O eq 'MSWin32') {
 		    $job->{pgid} = $job->{signal_pid};
 		}
-		if ($Forks::Super::Debug::DEBUG) {
+		if ($job->{debug}) {
 		    debug('parent forwarding signals for ', 
 			  $job->{real_pid}, ' to ', $job->{signal_pid});
 		}
@@ -1504,22 +1563,56 @@ sub _preconfig2 {
 	$job->{debug} = $Forks::Super::Debug::DEBUG;
     }
     if ($job->{daemon}) {
-	$job->{daemon_ipc} =
-	    Forks::Super::Job::Ipc::_choose_fh_filename(
-		'.daemon', purpose => 'daemon ipc');
-	if ($Forks::Super::Debug::DEBUG) {
-	    debug('Job will use ', $job->{daemon_ipc}, ' to get daemon pid.');
-	}
+        # we avoid pipes on Windows because they have tiny capacity
+        # and prone to deadlock. Those concerns are not so big for
+        # communicating the daemon pid ... do we want to
+        # try using pipes for this on Windows?
+        if (!&IS_WIN32) {
+            pipe my $p1, my $p2;
+            $p2->autoflush(1);
+            $job->{daemon_ipc_pipe} = [ $p1, $p2 ];
+            if ($job->{debug}) {
+                debug('Job will use pipe to get daemon pid');
+            }
+        } else {
+            $job->{daemon_ipc} =
+                Forks::Super::Job::Ipc::_choose_fh_filename(
+                    '.daemon', purpose => 'daemon ipc');
+            if ($job->{debug}) {
+                debug('Job will use ', $job->{daemon_ipc},
+                      ' to get daemon pid.');
+            }
+        }
     }
     if ($job->{style} eq 'cmd' 
 		|| (&IS_WIN32 && $job->{style} eq 'exec')
 		|| (&IS_WIN32 && ($job->{timeout} || $job->{expiration}))) {
-	$job->{signal_ipc} =
-	    Forks::Super::Job::Ipc::_choose_fh_filename(
-		'.signal', purpose => 'signal ipc', job => $job);
-	if ($Forks::Super::Debug::DEBUG) {
-	    debug('Job will use ', $job->{signal_ipc}, ' to get signal pid.');
-	}
+
+
+        if ($Forks::Super::SIGNAL_IPC_FILE 
+
+            # we avoid pipes on Windows because they have tiny capacity
+            # and prone to deadlock, but those are not large concerns
+            # for a low volume, single purpose communication channel
+            # like communicating the signal pid
+#           || &IS_WIN32
+            
+            || $job->{daemon}) {
+            $job->{signal_ipc} =
+                Forks::Super::Job::Ipc::_choose_fh_filename(
+                    '.signal', purpose => 'signal ipc', job => $job);
+            if ($job->{debug}) {
+                debug('Job will use ', $job->{signal_ipc},
+                      ' to get signal pid.');
+            }
+        } else {
+            pipe my $p1, my $p2;
+            $p2->autoflush(1);
+            $job->{signal_ipc_pipe} = [ $p1, $p2 ];
+            if ($job->{debug}) {
+                debug('Job will use pipe to get signal pid.');
+            }
+        }
     }
 
     if ($Forks::Super::Debug::DUMPSIG) {
@@ -1649,7 +1742,7 @@ sub _preconfig_busy_action {
     # make a queue priority available if needed
     #
     if (not defined $job->{queue_priority}) {
-	$job->{queue_priority} = Forks::Super::Queue::get_default_priority();
+	$job->{queue_priority} = Forks::Super::Deferred::get_default_priority();
     }
     return;
 }
@@ -1870,7 +1963,6 @@ sub _config_env_child {
 
 sub _config_debug_child {
     my $job = shift;
-#   if ($job->{debug} && $job->{undebug}) {
     if ($job->{undebug}) {
 	if ($Forks::Super::Config::IS_TEST) {
 	    debug("Disabling debugging in child $$");
@@ -1960,7 +2052,7 @@ sub __END {
 	} or do {
 	    $SIG{CHLD} = 'IGNORE';
 	};
-	Forks::Super::Queue::_cleanup();
+	Forks::Super::Deferred::_cleanup();
 	Forks::Super::Job::Ipc::_cleanup();
     } else {
         if (defined($this) && defined($this->{_cleanup_code})) {
@@ -2361,7 +2453,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 SYNOPSIS
 
@@ -2371,15 +2463,6 @@ Forks::Super::Job - object representing a background task
     $job = Forks::Super::Job::get($pid);
     $job = Forks::Super::Job::getByName($name);
 
-    print "Current job state is $job->{state}\n";
-    print "Job was created at ", scalar localtime($job->{created}), "\n";
-
-=head2 with overloading
-
-See L</"OVERLOADING">.
-
-    use Forks::Super 'overload';
-    $job = Forks::Super::fork( \%options );
     print "Process id of new job is $job\n";
     print "Current state is ", $job->state, "\n";
     waitpid $job, 0;
@@ -2624,6 +2707,22 @@ job name.
 
 =back
 
+=head3 getByName
+
+=over 4
+
+=item C< $job = Forks::Super::Job::getByName($name) >
+
+=item C< @jobs = Forks::Super::Job::getByName($name) >
+
+Looks up one or more C<Forks::Super::Job> objects by the
+or L<name|Forks::Super/"name"> attribute. In list context,
+returns all known jobs that have the given name. In scalar
+context, returns a single job object or C<undef> if no job
+has the specified name.
+
+=back
+
 =head3 count_active_processes
 
 =over 4
@@ -2702,7 +2801,8 @@ See L<Forks::Super::kill|Forks::Super/"kill">.
 
 When called on an active job, suspends the background process with 
 C<SIGSTOP> or other mechanism appropriate for the operating system.
-Returns a true value if it thinks it succeeded.
+Returns a true value if it thinks it succeeded. Unlike a C<SIGSTOP>
+signal, also operates on deferred jobs.
 
 =back
 
@@ -2715,7 +2815,7 @@ Returns a true value if it thinks it succeeded.
 When called on a suspended job (see L<< suspend|"$job->suspend" >>,
 above), resumes the background process with C<SIGCONT> or other mechanism 
 appropriate for the operating system. Returns a true value if it thinks
-it succeeded.
+it succeeded. Unlike a C<SIGCONT>, also operates on deferred jobs.
 
 =back
 
@@ -3043,7 +3143,7 @@ This method will
 
 =over 4
 
-=item * close any open filehandles
+=item * close any open filehandles associated with the job
 
 =item * attempt to remove temporary files used for interprocess
 communication with the job
@@ -3098,17 +3198,14 @@ from C<@ALL_JOBS> and C<%ALL_JOBS>.
 
 =head1 OVERLOADING
 
-An available feature in the L<Forks::Super|Forks::Super> module is to make
-it more convenient to access the functionality of 
-C<Forks::Super::Job>. When this feature is enabled, the 
-return value from a call to C<Forks::Super::fork()> is an
-I<overloaded> C<Forks::Super::Job> object. 
-
-    $job_or_pid = fork { %options };
-
-In a numerical context, this value looks and behaves like
-a process ID (or job ID). The value can be passed to functions
-like C<kill> and C<waitpid> that expect a process ID.
+A feature of the L<Forks::Super|Forks::Super> module is to make it
+more convenient to access information about a background process by
+returning a C<Forks::Super::Job> object instead of a simple
+numerical process id. A C<Forks::Super::Job> object is 
+L<overloaded|overload> to look and behave like a process ID (or job ID)
+in any numerical context. It can be passed to functions like C<kill>
+and C<waitpid> (even C<CORE::kill> and C<CORE::waitpid>) that
+expect to receive a process ID.
 
     if ($job_or_pid != $another_pid) { ... }
     kill 'TERM', $job_or_pid;
@@ -3132,31 +3229,6 @@ syntactically like a readable filehandle.
 
 Since v0.41, this feature is enabled by default.
 
-Whether the overloading is enabled by default or not, you can
-override the default behavior in three ways:
-
-=over 4
-
-=item 1. Set the environment variable C<FORKS_SUPER_JOB_OVERLOAD>
-to a true or false value
-
-    $ FORKS_SUPER_JOB_OVERLOAD=0 perl a_script_that_uses_Forks_Super.pl ...
-
-=item 2. Pass the parameter C<< overload >> to the module import function
-with a C<0> or C<1> value
-
-    use Forks::Super overload => 1;  # always enable overload feature
-
-=item 3. At runtime, call
-
-    Forks::Super::Job::enable_overload();
-    Forks::Super::Job::disable_overload();
-
-In principle you may call these methods at any time and as often 
-as you wish.
-
-=back
-
 Even when overloading is enabled, C<Forks::Super::fork()> 
 still returns a simple scalar value of 0 to the child process
 (when a value is returned).
