@@ -18,7 +18,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(run_callback);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 sub run_callback {
     my ($job, $callback) = @_;
@@ -55,12 +55,20 @@ sub _preconfig_callbacks {
     if (defined $job->{suspend}) {
 	$job->{suspend} = qualify_sub_name $job->{suspend};
     }
+    if (defined($job->{callback}) && 
+        (ref $job->{callback} eq '' || ref $job->{callback} eq 'CODE')) {
+	$job->{callback} = { finish => $job->{callback} };
+    }
+    # on_start, on_queue, on_fail, on_finish, etc. are top-level synonyms for
+    # callback { start => ..., queue => ..., fail => ..., finish => ... }
+    foreach my $syn (qw(start queue fail finish reaped)) {
+        if (defined $job->{"on_" . $syn}) {
+            $job->{callback}{$syn} ||= delete $job->{"on_" . $syn};
+        }
+    }
     if (!defined $job->{callback}) {
 	return;
     }
-    if (ref $job->{callback} eq '' || ref $job->{callback} eq 'CODE') {
-	$job->{callback} = { finish => $job->{callback} };
-    }
     if (defined $job->{callback}{finish} && $job->{daemon}) {
 	carp 'Forks::Super::_preconfig_callbacks: ',
               "'finish' callback is not going to be called ",
