@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
@@ -297,11 +297,9 @@ sub _safeopen_open {
     my ($fh, $open2, $open3) = @_;
     my $result;
     if (defined $open3) {
-        no warnings 'io';
 	$result = CORE::open($fh, $open2, $open3);      ## no critic (BriefOpen)
 	$_[0] = $fh;
     } else {
-        no warnings 'io';
 	$result = CORE::open($fh, $open2);              ## no critic (BriefOpen)
 	$_[0] = $fh;
     }
@@ -837,15 +835,14 @@ sub _create_socket_pair {
 	croak "Forks::Super::Job::_create_socket_pair(): no Socket\n";
     }
     my ($s_child, $s_parent);
+    my $addr_family = Socket::AF_UNIX();
     local $! = undef;
     if (Forks::Super::Config::CONFIG('IO::Socket') && 0) {
 	($s_child, $s_parent) = IO::Socket->socketpair(
-	    Socket::AF_UNIX(), Socket::SOCK_STREAM(), Socket::PF_UNSPEC());
+	    $addr_family, Socket::SOCK_STREAM(), Socket::PF_UNSPEC());
 	if (!(defined($s_child) && defined($s_parent))) {
 	    warn 'Forks::Super::_create_socket_pair: ',
-	    	"IO::Socket->socketpair(AF_UNIX) failed. Trying AF_INET\n";
-	    ($s_child, $s_parent) = IO::Socket->socketpair(
-		Socket::AF_INET(), Socket::SOCK_STREAM(), Socket::PF_UNSPEC());
+	    	"IO::Socket->socketpair(AF_UNIX) failed.\n";
 	}
     } else {
 
@@ -853,12 +850,12 @@ sub _create_socket_pair {
 	$s_child = _gensym();
 	$s_parent = _gensym();
 
-	my $z = socketpair($s_child, $s_parent, Socket::AF_UNIX(),
+	my $z = socketpair($s_child, $s_parent, $addr_family,
 			   Socket::SOCK_STREAM(), Socket::PF_UNSPEC());
 	if ($z == 0) {
 	    warn 'Forks::Super::_create_socket_pair: ',
-	    	"socketpair(AF_UNIX) failed. Trying AF_INET\n";
-	    $z = socketpair($s_child, $s_parent, Socket::AF_INET(),
+                 "socketpair(AF_UNIX) failed. Trying again\n";
+	    $z = socketpair($s_child, $s_parent, $addr_family,
 			    Socket::SOCK_STREAM(), Socket::PF_UNSPEC());
 	    if ($z == 0) {
 		undef $s_child;
@@ -1573,7 +1570,6 @@ sub __config_fh_parent_stdin_pipes {
     my $job = shift;
     my $fh_config = $job->{fh_config};
     if ($USE_TIE_PH) {
-        no warnings 'io';
 	my $ph = _gensym();
 	tie *$ph, 'Forks::Super::Tie::IPCPipeHandle',
                 $fh_config->{p_to_in}, $ph;
@@ -1609,7 +1605,7 @@ sub __config_fh_parent_stdin_file {
 	  = $Forks::Super::CHILD_STDIN{$job->{real_pid}}
 	  = $fh;
 	$Forks::Super::CHILD_STDIN{$job->{pid}} = $fh;
-	$fh->autoflush(1);
+        $job->{child_stdin}->autoflush(1);
 
         debug('Opened child STDIN (',fileno($fh),') in parent')
             if $job->{debug};
@@ -1684,7 +1680,6 @@ sub __config_fh_parent_stdout_pipes {
     my $fh_config = $job->{fh_config};
 
     if ($USE_TIE_PH) {
-        no warnings 'io';
 	my $ph = _gensym();
 	tie *$ph, 'Forks::Super::Tie::IPCPipeHandle', $fh_config->{p_out}, $ph;
 	$job->{child_stdout}
@@ -1818,8 +1813,6 @@ sub __config_fh_parent_stderr_pipes {
     my $fh_config = $job->{fh_config};
 
     if ($USE_TIE_PH) {
-        no warnings 'io';
-        
 	my $ph = _gensym();
 	tie *$ph, 'Forks::Super::Tie::IPCPipeHandle', $fh_config->{p_err}, $ph;
 
@@ -1924,10 +1917,12 @@ sub _config_fh_child_stdin {
     my $fh_config = $job->{fh_config};
     if ($fh_config->{suppress} && $fh_config->{suppress}{in}) {
 	close STDIN;
+        open STDIN, '<', Forks::Super::Util::DEVNULL();
 	return;
     }
     if (!$fh_config->{in}) {
 	close STDIN;
+        open STDIN, '<', Forks::Super::Util::DEVNULL();
 	return;
     }
 
@@ -2016,7 +2011,6 @@ sub __config_fh_child_stdin_sockets {
 
 sub __config_fh_child_stdin_pipes {
     my $job = shift;
-    no warnings 'io';
     my $fh_config = $job->{fh_config};
     push @{$job->{child_fh_close}}, $fh_config->{p_in};
     close STDIN;
@@ -2054,9 +2048,13 @@ sub __config_fh_child_stdin_file {
 	    _safeopen($job, *STDIN, '<&', $fh, robust => 1)
 		or warn 'Forks::Super::Job::config_fh_child(): ',
 	    	        'could not attach child STDIN ',
-		        "to input file handle: $!\n";
+                "to input file handle: $!\n";
+        } elsif (0) {
+	    _safeopen($job, *STDIN, '<&', $fh, robust => 1)
+		or warn 'Forks::Super::Job::config_fh_child(): ',
+	    	        'could not attach child STDIN ',
+                "to input file handle: $!\n";
 	} else {
-	    # require Forks::Super::Tie::IPCDupSTDIN;
 	    tie *STDIN, 'Forks::Super::Tie::IPCDupSTDIN', 
 	        GLOB => $fh, 
 	        JOB => &Forks::Super::Job::this,
@@ -2078,6 +2076,7 @@ sub _config_fh_child_stdout {
     my $fh_config = $job->{fh_config};
     if ($fh_config->{suppress} && $fh_config->{suppress}{out}) {
 	close STDOUT;
+        open STDOUT, '>', Forks::Super::Util::DEVNULL();
 	return;
     }
     return if ! $fh_config->{out};
@@ -2098,7 +2097,6 @@ sub _config_fh_child_stdout {
 
 sub __config_fh_child_stdout_sockets {
     my $job = shift;
-    no warnings 'io';
     my $fh_config = $job->{fh_config};
 
     close STDOUT;
@@ -2135,7 +2133,6 @@ sub __config_fh_child_stdout_sockets {
 
 sub __config_fh_child_stdout_pipes {
     my $job = shift;
-    no warnings 'io';
     my $fh_config = $job->{fh_config};
     close STDOUT;
     if ($USE_TIE_PH) {
@@ -2222,6 +2219,7 @@ sub _config_fh_child_stderr {
     my $fh_config = $job->{fh_config};
     if ($fh_config->{suppress} && $fh_config->{suppress}{err}) {
 	close STDERR;
+        open STDERR, '>', Forks::Super::Util::DEVNULL();
 	return;
     }
     return if ! $fh_config->{err};
@@ -2268,7 +2266,6 @@ sub __config_fh_child_stderr_sockets {
 
 sub __config_fh_child_stderr_pipes {
     my $job = shift;
-    no warnings 'io';
     my $fh_config = $job->{fh_config};
 
     push @{$job->{child_fh_close}}, $fh_config->{p_to_err};
@@ -2447,6 +2444,7 @@ sub _config_cmd_fh_child {
 	}
     } elsif (!$job->{is_emulation}) {
         close STDIN;
+        open STDIN, '<', Forks::Super::Util::DEVNULL();
     }
     debug("config_cmd_fh_config(): child cmd is   $cmd[0]  ")
 	if $job->{debug};
@@ -3380,7 +3378,7 @@ Forks::Super::Job::Ipc - interprocess communication routines for Forks::Super
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 DESCRIPTION
 
