@@ -18,7 +18,7 @@ use warnings;
 use constant FOREVER => 9E9;
 use constant LONG_TIME => 9E8;
 
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 our $MAIN_PID = $$;
 our $DISABLE_INT = 0;
@@ -264,12 +264,12 @@ sub _child_timeout_Win32 {
 	my $p = $job->{signal_pid};
 	my $c1 = Forks::Super::Job::OS::Win32::terminate_process_tree(
 	    $p, $signo);
-	$DEBUG && debug("killed process tree for signal pid $p: $c1");
+	$job->{debug} && debug("killed process tree for signal pid $p: $c1");
     }
     if ($pid && $pid > 0 && $pid != $job->{signal_pid}) {
 	my $c2 = Forks::Super::Job::OS::Win32::terminate_process_tree(
 	    $pid, $signo);
-	$DEBUG && debug("killed process tree for system1 pid $pid: $c2");
+	$job->{debug} && debug("killed process tree for system1 pid $pid: $c2");
     }
     return;
 }
