@@ -14,7 +14,7 @@ use warnings;
 our ($_SIGCHLD, $_SIGCHLD_CNT, $REAP) = (0,0,0);
 our (@CHLD_HANDLE_HISTORY, @SIGCHLD_CAUGHT) = (0);
 our $SIG_DEBUG = $ENV{SIG_DEBUG};
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 my %bastards;
 
 #
@@ -97,15 +97,16 @@ sub handle_CHLD {
     }
     $_SIGCHLD--;
     if ($nhandled > 0) {
-	Forks::Super::Queue::check_queue();
+	Forks::Super::Deferred::check_queue();
     }
     return;
 }
 
 sub _preliminary_reap {
     my ($pid,$status) = @_;
+    my $j = $Forks::Super::ALL_JOBS{$pid};
     $REAP = 1;
-    if ($DEBUG) {
+    if ($j->{debug}) {
 	debug('handle_CHLD(): preliminary reap for ',
 	      "$pid status=$status");
     }
@@ -116,7 +117,6 @@ sub _preliminary_reap {
     }
 
     $REAP = 1;
-    my $j = $Forks::Super::ALL_JOBS{$pid};
     if (!$j->{daemon}) {
 	$j->{status} = $status;
 	$j->_mark_complete;
@@ -201,7 +201,3 @@ We want a framework where we can add and remove jobs
 for the signal handlers to do at will. If end user
 also wishes to add a signal handler, the framework
 should be able to accomodate that, too. And transparently.
-
-
-
-
