@@ -6,8 +6,9 @@ use Time::HiRes;
 use POSIX ':sys_wait_h';
 use IPC::SysV qw(IPC_PRIVATE S_IRUSR S_IWUSR IPC_CREAT IPC_NOWAIT);
 use IPC::Semaphore;
+use Forks::Super::Util qw(DEVNULL DEVTTY Ctime);
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 our $NOWAIT_YIELD_DURATION = 0.05;
 
@@ -30,7 +31,13 @@ sub new {
 	carp "IPC::Semaphore constructor failed: $@";
 	return;
     }
-    $self->{sems}->setall((0) x $count);
+
+    # set initial semaphore values before fork
+    my @set = map { $_ eq 'P' || $_ eq 'C' ? 1 : 0 } @initial;
+    push @set, (0) x $count;
+    @set = splice @set, 0, $count;
+    $self->{sems}->setall(@set);
+
     return $self;
 }
 
@@ -41,7 +48,9 @@ sub _releaseAfterFork {
     my $label = $self->{label} = $$ == $self->{ppid} ? "P" : "C";
     for my $i (0 .. $self->{count}-1) {
 	if ($self->{initial}[$i] eq $label) {
-	    $self->acquire($i);
+            # semaphore was already acquired before the fork
+            # but we need to set $self->{acquired};
+            $self->{acquired}[$i] = 1;
 	}
     }
     return;
@@ -49,21 +58,25 @@ sub _releaseAfterFork {
 
 sub release {
     my ($self, $n) = @_;
-    return if $n < 0 || $n >= $self->{count};
-    if ($n < 0 || $self->{acquired}[$n]) {
-	$self->{sems} && $self->{sems}->setval($n, 0);
-	$self->{acquired}[$n] = 0  if $n >= 0;
+    if ($n < 0 || $n >= $self->{count}) {
+        return;
+    }
+    if ($self->{acquired}[$n]) {
+	$self->{sems} && $self->{sems}->op($n, -1, 0);
+	$self->{acquired}[$n] = 0;
 	return 1;
     }
     return;
 }
 
-# robuster version of  $self->{sems}->op($n,0,FLAGS)
+# robuster version of  $self->{sems}->op($n,0,FLAGS, $n,1,FLAGS)
 # detects when partner process has died without removing the semaphore
-# return true if successfully waited on lock
+# return true if successfully waited on lock and incremented the semaphore
 sub _wait_on {
     my ($self, $n, $expire) = @_;
-    return 1 if !$self->{sems};
+    if (!$self->{sems}) {
+        return 1;
+    }
 
     my $partner = $$ == $self->{ppid} ? $self->{childPid} : $self->{ppid};
 
@@ -77,9 +90,13 @@ sub _wait_on {
 	    delete $self->{sems};
 	    return $Forks::Super::Sync::SYNC_PARTNER_GONE + 0.1;
 	}
+        if (!$self->{sems}) {
+            carp "sync::_wait_on: semaphore resource not available";
+            return 4;
+        }
 
-	my $z = $self->{sems} && $self->{sems}->op($n, 0, &IPC_NOWAIT);
-
+	my $z = $self->{sems}->op($n, 0, &IPC_NOWAIT,
+                                  $n, 1, 0);
 	if ($z) {
 	    return 1;
 	} elsif ($!{EINVAL}) {  # semaphore was removed
@@ -100,8 +117,9 @@ sub _wait_on {
 	    return $Forks::Super::Sync::SYNC_PARTNER_GONE;
 	}
 	Time::HiRes::sleep( $NOWAIT_YIELD_DURATION );
-	waitpid -1, &WNOHANG;
+	my $z5 = waitpid -1, &WNOHANG;
     }
+    return; # unreachable
 }
 
 sub acquire {
@@ -120,10 +138,7 @@ sub acquire {
     }
     my $z = $self->_wait_on($n, $expire);
     if ($z > 0) {
-	if ($n >= 0) {
-	    $self->{acquired}[$n] = 1;
-	}
-	$self->{sems} && $self->{sems}->setval($n,1);
+        $self->{acquired}[$n] = 1;
     }
 
     if ($z > 1) {
