@@ -7,7 +7,7 @@ use POSIX ':sys_wait_h';
 use Win32::Semaphore;
 
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 our $NOWAIT_YIELD_DURATION = 250;
 my @RELEASE_ON_EXIT = ();
 
@@ -217,7 +217,8 @@ L<Win32::Semaphore|Win32::Semaphore>.
 
 Advantages: fast, doesn't create files or use filehandles
 
-Disadvantages: Windows only.
+Disadvantages: Windows only. And I have unverified concerns about
+what it will do if a lock-holder exits ungracefully.
 
 =head1 SEE ALSO
 
