@@ -29,7 +29,7 @@ use strict;
 use warnings;
 
 our @ISA = qw(Exporter IO::Handle);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 sub TIEHANDLE {
     my ($class, %props) = @_;
@@ -58,10 +58,6 @@ sub OPEN {
 	if (defined $expr) {
 	    # XXX - we currently don't make calls with the 4+ arg version of open
 	    #       so we don't need to support it now, but one day we might.
-
-	    # suppress "Filehandle %s reopened as %s only for input/output",
-	    # which can occur when we close and reopen the STDxxx filehandles
-	    no warnings 'io';
 	    $result = open *$self, $mode, $expr;
 	} else {
 	    $result = open *$self, $mode;         ## no critic (TwoArgOpen)
