@@ -16,9 +16,9 @@ use constant IS_CYGWIN => $^O =~ /cygwin/i;
 use constant IS_WIN32ish => &IS_WIN32 || &IS_CYGWIN;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name 
-		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl);
+		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl DEVNULL DEVTTY);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 our (%SIG_NO, @SIG_NAME, $Time_HiRes_avail,
@@ -105,7 +105,7 @@ sub isValidPid {
     return 0 if !defined($pid) || !is_number($pid);
     if (&IS_WIN32) {
 	# -200000 is too high to be a pseudo-process id on Windows?
-	# also see &Forks::Super::Queue::FIRST_DEFERRED_ID
+	# also see &Forks::Super::Deferred::FIRST_DEFERRED_ID
 	return $pid > 0 || ($pid > -200000 && $pid <= -2);
     } else {
 	return $pid > 0;
@@ -358,6 +358,14 @@ sub okl {
     }
 }
 
+sub DEVNULL {
+    &IS_WIN32 ? "nul" : "/dev/null";
+}
+
+sub DEVTTY {
+    &IS_WIN32 ? "con" : "/dev/tty";
+}
+
 1;
 
 =head1 NAME
@@ -366,7 +374,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 SYNOPSIS
 
@@ -532,7 +540,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2013, Marty O'Brien.
+Copyright (c) 2009-2016, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
