@@ -8,7 +8,7 @@ use Forks::Super::Job;
 use Forks::Super::Util qw(is_number isValidPid IS_WIN32);
 use Forks::Super::Debug qw(:all);
 use Forks::Super::Config;
-use Forks::Super::Queue;
+use Forks::Super::Deferred;
 use Forks::Super::SysInfo;
 use Forks::Super::Tie::Enum;
 use Signals::XSIG;
@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -401,9 +401,9 @@ sub _block_until_job_completes {
 	__run_productive_waitpid_code();
 	Forks::Super::Util::pause();
 	if ($job->{state} =~ /DEFER|SUSPEND/) {
-	    Forks::Super::Queue::check_queue();
+	    Forks::Super::Deferred::check_queue();
 	}
-        if ($DEBUG > 1) {
+        if ($job->{debug} > 1) {
             debug("    blocking on $job state is $job->{state}");
         }
     }
@@ -446,7 +446,7 @@ sub _waitpid_name {
 	__run_productive_waitpid_code();
 	Forks::Super::Util::pause();
 	if (grep {$_->{state} eq 'DEFERRED'} @jobs_to_wait_for) {
-	    Forks::Super::Queue::run_queue();
+	    Forks::Super::Deferred::run_queue();
 	}
 	@jobs = grep { $_->{state} eq 'COMPLETE' 
 			   || $_->{state} eq 'REAPED'} @jobs_to_wait_for;
@@ -532,7 +532,7 @@ Forks::Super::Wait
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 DESCRIPTION
 
@@ -549,7 +549,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2015, Marty O'Brien.
+Copyright (c) 2009-2016, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
