@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(untied %DEFAULT_BEHAVIOR);
 our %DEFAULT_BEHAVIOR;
 *DEFAULT_BEHAVIOR = \%Signals::XSIG::Default::DEFAULT_BEHAVIOR;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 our (%XSIG, %_XSIG, %SIGTABLE, $_REFRESH, $_DISABLE_WARNINGS);
 our $_INITIALIZED = 0;
 our $SIGTIE = bless {}, 'Signals::XSIG::TieSIG';
@@ -28,6 +28,16 @@ our $TIEARRAY_CLASS = 'Signals::XSIG::TieArray';
 my %TIEDSCALARS = (); # map signal names to S::X::TiedScalar objs
 my %alias = ();
 
+BEGIN {
+    # how to detect global destruction. Idea from Devel::GlobalDestruction 0.13
+    if (defined ${^GLOBAL_PHASE}) {
+        eval 'sub __inGD() {${^GLOBAL_PHASE} eq "DESTRUCT" && __END()}; 1';
+    } else {
+        require B;
+        eval 'sub __inGD() { ${B::main_cv()}==0 && __END();}; 1';
+    }
+}
+
 &_init;
 
 sub _init {
@@ -86,16 +96,18 @@ sub __shadow__die__handler  {          ## no critic (Unpacking)
     return &__shadow_signal_handler('__DIE__',@_) 
 }
 
-our $_GLOBAL_DESTRUCTION = 0;
-END {
-    $_GLOBAL_DESTRUCTION = 1; 
+END { &__END; }
+
+sub __END {
+    no warnings 'redefine';
+    *__inGD = sub () { 1 };
 }
 
 sub __shadow_signal_handler {
     my ($signal, @args) = @_;
 
     # %XSIG might be partially or completely untied during global destruction
-    return if $_GLOBAL_DESTRUCTION;
+    return if __inGD();
     my $seen_default = 0;
 
     my $h = tied @{$XSIG{$signal}};
@@ -269,8 +281,7 @@ sub Signals::XSIG::TieSIG::CLEAR {
 
 sub Signals::XSIG::TieSIG::EXISTS {
     my ($self,$key) = @_;
-    my $z = untied { exists $SIG{$key} };
-    return $z;
+    return untied { exists $SIG{$key} };
 }
 
 sub Signals::XSIG::TieSIG::FIRSTKEY {
@@ -486,9 +497,12 @@ sub Signals::XSIG::TieScalar::FETCH {
     my $key = my $key2 = $self->{key};
     Signals::XSIG::_resolve_signal($key);
     if ($key ne $key2 && !$self->{copied}) {
-	print STDERR "\$XSIG{$key2\} copied from \$XSIG{$key}\n";
-	$self->{val} = (tied $Signals::XSIG::XSIG{$key})->FETCH;
+        #print STDERR "\$XSIG{$key2\} copied from \$XSIG{$key}\n";
+	$self->{val} = (tied $Signals::XSIG::_XSIG{$key})->FETCH;
 	$self->{copied} = $key;
+        push @{(tied $Signals::XSIG::_XSIG{$key})->{aliases}}, $key2;
+    } elsif ($self->{copied}) {
+        $self->{val} = $Signals::XSIG::_XSIG{ $self->{copied} };
     }
     return $self->{val};
 }
@@ -507,8 +521,8 @@ sub Signals::XSIG::TieScalar::STORE {
 	my $key = $self->{key};
 	$self->{val} = [];
 	tie @{$self->{val}}, 
-	$TIEARRAY_CLASS,
-	$self->{key}, @$value;
+	    $TIEARRAY_CLASS,
+	    $self->{key}, @$value;
 	(tied @{$self->{val}})->_refresh_SIG;
 	return $old;
     }
@@ -535,11 +549,13 @@ sub Signals::XSIG::TieXSIG::TIEHASH {
 
 sub Signals::XSIG::TieXSIG::FETCH {
     my ($self,$key) = @_;
+    _resolve_signal($key,1);
     return $_XSIG{$key};
 }
 
 sub Signals::XSIG::TieXSIG::STORE {
     my ($self, $key, $value) = @_;
+    _resolve_signal($key,1);
     my $old = $_XSIG{$key};
     # (tied $_XSIG{$key})->STORE($key,$value); #
     $_XSIG{$key} = $value;
@@ -548,6 +564,7 @@ sub Signals::XSIG::TieXSIG::STORE {
 
 sub Signals::XSIG::TieXSIG::DELETE {
     my ($self, $key) = @_;
+    _resolve_signal($key,1);
     my $old = $_XSIG{$key};
     $XSIG{$key} = [];
     return $old;
@@ -578,6 +595,7 @@ sub Signals::XSIG::TieXSIG::CLEAR {
 
 sub Signals::XSIG::TieXSIG::EXISTS {
     my ($self,$key) = @_;
+    _resolve_signal($key,1);
     return exists $_XSIG{$key};
 }
 
@@ -602,7 +620,7 @@ Signals::XSIG - install multiple signal handlers through %XSIG
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 SYNOPSIS
 
@@ -1024,7 +1042,7 @@ _head1 ACKNOWLEDGEMENTS
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2013 Marty O'Brien.
+Copyright 2010-2016 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
