@@ -15,7 +15,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(%DEFAULT_BEHAVIOR);
 
 our %DEFAULT_BEHAVIOR;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 my @snam = split ' ', $Config{sig_name};
 my @snum = split ' ', $Config{sig_num};
@@ -331,6 +331,11 @@ ZERO    [0] => IGNORE
 __DIE__ [] => IGNORE
 __WARN__ [] => IGNORE
 
+[aix]
+AIO	[]   => IGNORE
+POLL	[]   => IGNORE
+SEGV    [11] => TERMINATE 11
+
 [cygwin]
 ABRT    [6] => TERMINATE 134
 ALRM    [14] => TERMINATE 14
