@@ -257,7 +257,7 @@ sub main {
 
 	    if ($debug) {
 		color_print(DEBUG => 'Queue size: ',
-			    scalar @Forks::Super::Queue::QUEUE, "\n");
+			    scalar @Forks::Super::Deferred::QUEUE, "\n");
 	    }
 
 	    # see if any tests have finished lately
@@ -598,11 +598,11 @@ sub process_test_output {
     my $num_dequeued = 0;
     my $num_terminated = 0;
     if ($total_status > 0 && $abort_on_first_error) {
-	foreach my $j (@Forks::Super::Queue::QUEUE) {
+	foreach my $j (@Forks::Super::Deferred::QUEUE) {
 	    $j->_mark_complete;
 	    $j->{status} = -1;
 	    $num_dequeued++;
-	    Forks::Super::Queue::queue_job();
+	    Forks::Super::Deferred::queue_job();
 	}
 	foreach my $j (@Forks::Super::ALL_JOBS) {
 	    next if ref $j ne 'Forks::Super::Job';
@@ -761,10 +761,10 @@ sub maxproc_initial {
     if (@mask < $n) {
 	$n = @mask || $n;
     }
-    return $n < 10 ? int(2 * $n + 1) : $n + 6;
+    return $n < 8 ? int(2 * $n + 1) : 16;
 }
 
-# if appropriate and suppported, enhance output to STDOUT with color.
+# if appropriate and supported, enhance output to STDOUT with color.
 sub color_print {
     my ($color, @msg) = @_;
     if ($color eq '' || !$use_color) {
@@ -826,7 +826,7 @@ forked_harness.pl - run tests in parallel with Forks::Super
 
 =head1 VERSION
 
-0.86
+0.87
 
 =head1 SYNOPSIS
 
@@ -1178,7 +1178,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2015, Marty O'Brien.
+Copyright (c) 2010-2016, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
